@@ -18,7 +18,12 @@ from .excel_operation import (
 from .milestone import Milestone
 from .priority import Priority
 from .sprint_schedule import SprintScheduleStore
-from .story import Story, StoryFactory, raise_story_sequence_by_property, sort_stories
+from .story import (
+    Story,
+    StoryFactory,
+    sort_stories_by_property_and_order,
+    sort_stories_by_raise_ranking,
+)
 
 __version__ = version("sharry_jira_tool")
 
@@ -33,8 +38,8 @@ __all__ = [
     "SprintScheduleStore",
     "Story",
     "StoryFactory",
-    "sort_stories",
-    "raise_story_sequence_by_property",
+    "sort_stories_by_property_and_order",
+    "sort_stories_by_raise_ranking",
 ]
 
 del metadata
