@@ -2,7 +2,6 @@
 """
 This module offers a set of operations that user can modify their excel files.
 """
-import logging
 import os
 import pathlib
 import warnings
@@ -61,12 +60,18 @@ def read_excel_file(
     wb = openpyxl.load_workbook(file)
     sheet = wb.active
 
-    columns = []
+    # The count of column is taking from the defination file to avoid too many columns inside the excel file.
+    # Also, need to avoid exceed the range of the actual count.
+    if excel_defination.column_count > sheet.max_column:
+        column_count = sheet.max_column
+    else:
+        column_count = excel_defination.column_count
 
-    max_column_index = chr(65 + sheet.max_column - 1)
+    max_column_index = chr(65 + column_count - 1)
 
     start_column = "A1"
     end_column = f"{max_column_index}1"
+    columns = []
 
     for cells in sheet[start_column:end_column]:
         if len(columns) > 0:
@@ -169,18 +174,22 @@ def output_to_excel_file(
 
     excel_defination_columns = excel_defination.get_columns()
 
+    # Use original excel column name first.
     columns = columns_in_excel
     if columns is None:
-        columns = [column_name for _, column_name, _, _, _ in excel_defination_columns]
+        columns = [
+            column_name for _, column_name, _, _, _, _, _ in excel_defination_columns
+        ]
 
     for column_index in range(len(columns)):
         cell = sheet.cell(row=1, column=column_index + 1)
         cell.value = columns[column_index]
 
-    for row_index in range(len(stories)):
-        for column_index, column_name, _, _, _, _ in excel_defination_columns:
-            cell = sheet.cell(row=row_index + 2, column=column_index)
-            cell.value = stories[row_index].format_value(column_name)
+    if stories is not None:
+        for row_index in range(len(stories)):
+            for column_index, column_name, _, _, _, _, _ in excel_defination_columns:
+                cell = sheet.cell(row=row_index + 2, column=column_index)
+                cell.value = stories[row_index].format_value(column_name)
 
     wb.save(file)
     wb.close()
@@ -189,8 +198,8 @@ def output_to_excel_file(
 def process_excel_file(
     input_file: str,
     output_file: str,
-    sprint_schedule_config: str = None,
     excel_defination_config: str = None,
+    sprint_schedule_config: str = None,
     over_write: bool = True,
 ):
     """
@@ -216,18 +225,26 @@ def process_excel_file(
         sprint_schedule.load(
             files("jira_tool.assets").joinpath("sprint_schedule.json").read_text()
         )
-        print("Loading default sprint schedule...")
+        print("Using default sprint schedule...")
     else:
         sprint_schedule.load_file(sprint_schedule_config)
+        print("Using custom sprint schedule...")
 
     excel_defination = ExcelDefination()
     if excel_defination_config is None:
         excel_defination.load(
             files("jira_tool.assets").joinpath("excel_defination.json").read_text()
         )
-        print("Loading default excel defination...")
+        print("Using default excel defination...")
     else:
         excel_defination.load_file(excel_defination_config)
+        print("Using custom excel defination...")
+
+    validation_result = excel_defination.validate()
+    if len(validation_result) != 0:
+        for item in validation_result:
+            print(item)
+        return
 
     excel_columns, stories = read_excel_file(
         input_file, excel_defination, sprint_schedule
@@ -237,10 +254,15 @@ def process_excel_file(
         print("There are no stories inside the excel file.")
         return
 
-    stories = sorted(stories, reverse=True)
-    sort_stories(stories, excel_defination)
-    # stories = raise_story_sequence_by_property(stories, "override")
-    # stories = raise_story_sequence_by_property(stories, "deferred")
+    sort_strategy_priorities = excel_defination.get_sort_strategy_priorities()
+
+    for sort_strategy in sort_strategy_priorities:
+        if sort_strategy.lower() in "InlineWeights".lower():
+            stories = sorted(stories, reverse=True)
+        elif sort_strategy.lower() in "SortOrder".lower():
+            sort_stories_by_property_and_order(stories, excel_defination)
+        elif sort_strategy.lower() in "RaiseRanking".lower():
+            stories = sort_stories_by_raise_ranking(stories, excel_defination)
 
     output_to_excel_file(
         output_file, stories, excel_defination, excel_columns, over_write
