@@ -51,23 +51,8 @@ class SprintScheduleStore:
             raise ValueError(f"The file is not exist. File: {file}")
 
         with open(file=file, mode="r") as schedule_file:
-            raw_data = json.load(schedule_file)
-
-            priority = 0
-            sprints = []
-            for item in raw_data:
-                for key, value in item.items():
-                    if key.lower() in "priority":
-                        priority = value
-                    if key.lower() in "sprints":
-                        for sprint in value:
-                            if len(sprint) > 0:
-                                sprints.append(sprint)
-
-                for sprint in sprints:
-                    self.store.append((sprint, priority))
-                sprints.clear()
-                priority = 0
+            self.load(schedule_file.read())
+            schedule_file.close()
 
     def get_priority(self, sprint: str) -> int:
         for item in self.store:
