@@ -16,8 +16,8 @@ __all__ = [
     "convert_to_bool",
     "convert_to_datetime",
     "convert_to_decimal",
-    "sort_stories",
-    "raise_story_sequence_by_property",
+    "sort_stories_by_property_and_order",
+    "sort_stories_by_raise_ranking",
 ]
 
 
@@ -85,6 +85,9 @@ class Story(object):
                 return "Yes"
             else:
                 return "No"
+        # TODO: Support customized format string in JSON.
+        elif type(property) is float:
+            return str(property)
         else:
             return str(property)
 
@@ -106,6 +109,7 @@ class Story(object):
     def __setitem__(self, property_name, property_value):
         self.set_value(type(property_value), property_name, property_value)
 
+    # Currently, comparing story only consider the Priority properties.
     def __lt__(self, __o: object) -> bool:
         return self.factory.compare_story(self, __o) < 0
 
@@ -121,10 +125,14 @@ class Story(object):
     def __eq__(self, __o: object) -> bool:
         return self.factory.compare_story(self, __o) == 0
 
+    # For CSV consideration.
     def __str__(self):
-        separator = ", "
         result = ""
-        for _, column_name, _, _, _, _ in self.factory.columns:
+        if self is None:
+            return result
+
+        separator = ", "
+        for _, column_name, _, _, _, _, _ in self.factory.columns:
             if hasattr(self, column_name):
                 result += f"{str(getattr(self, column_name))}{separator}"
         return result
@@ -139,9 +147,9 @@ class StoryFactory(object):
 
     def __generate_compare_rules(self) -> "list[tuple]":
         compare_rules = []
-        for _, column_name, _, _, _, priority in self._columns:
-            if priority > 0:
-                compare_rules.append((column_name, priority))
+        for _, column_name, _, _, _, inline_weights, _ in self._columns:
+            if inline_weights > 0:
+                compare_rules.append((column_name, inline_weights))
         compare_rules.sort(key=lambda r: r[1], reverse=True)
         return compare_rules
 
@@ -234,23 +242,58 @@ class StoryFactory(object):
         return 0
 
 
-def sort_stories(stories: "list[Story]", excel_defination: ExcelDefination):
-    sort_rule = []
+def sort_stories_by_property_and_order(
+    stories: "list[Story]", excel_defination: ExcelDefination
+):
+    sort_rules = []
     excel_defination_columns = excel_defination.get_columns()
 
-    for _, column_name, _, need_sort, sort_desc_or_asc, _ in excel_defination_columns:
-        if need_sort is True:
-            sort_rule.append((column_name, sort_desc_or_asc))
+    for _, column_name, _, require_sort, sort_order, _, _ in excel_defination_columns:
+        if require_sort is True:
+            sort_rules.append((column_name, sort_order))
 
-    _internal_sort_stories(stories, sort_rule)
+    _internal_sort_stories_by_property_and_order(stories, sort_rules)
 
 
-def _internal_sort_stories(stories: "list[Story]", keys: "list[tuple]"):
-    for key, isReversed in reversed(keys):
-        stories.sort(key=attrgetter(key), reverse=isReversed)
+def _internal_sort_stories_by_property_and_order(
+    stories: "list[Story]", sort_rules: "list[tuple]"
+):
+    for column_name, sort_order in reversed(sort_rules):
+        stories.sort(key=attrgetter(column_name), reverse=sort_order)
 
 
-def raise_story_sequence_by_property(
+def sort_stories_by_raise_ranking(
+    stories: "list[Story]", excel_defination: ExcelDefination
+) -> "list[Story]":
+    sort_rules = []
+    excel_defination_columns = excel_defination.get_columns()
+
+    for (
+        _,
+        column_name,
+        _,
+        _,
+        _,
+        _,
+        ranking,
+    ) in excel_defination_columns:
+        if ranking > 0:
+            sort_rules.append((column_name, ranking))
+
+    if len(sort_rules) == 0:
+        return stories
+
+    sort_rules.sort(key=lambda x: x[1], reverse=True)
+
+    result = None
+
+    for property_name, _ in sort_rules:
+        result = _raise_story_ranking_by_property(stories, property_name)
+
+    return result
+
+
+def _raise_story_ranking_by_property(
     stories: "list[Story]", property_name: str
 ) -> "list[Story]":
     if stories is None or len(stories) == 0:
